@@ -12,7 +12,7 @@ use Padre::Locale   ();
 use Padre::Wx       ();
 use Padre::Wx::Menu ();
 
-our $VERSION = '0.49';
+our $VERSION = '0.50';
 our @ISA     = 'Padre::Wx::Menu';
 
 
@@ -117,6 +117,12 @@ sub new {
 	return $self;
 }
 
+sub title {
+	my $self = shift;
+
+	return Wx::gettext('&Help');
+}
+
 sub refresh {
 	my $self    = shift;
 	my $current = _CURRENT(@_);
