@@ -10,7 +10,7 @@ use Padre::Current qw{_CURRENT};
 use Padre::Wx       ();
 use Padre::Wx::Menu ();
 
-our $VERSION = '0.49';
+our $VERSION = '0.50';
 our @ISA     = 'Padre::Wx::Menu';
 
 
@@ -97,6 +97,12 @@ sub new {
 	return $self;
 }
 
+sub title {
+	my $self = shift;
+
+	return Wx::gettext('&Search');
+}
+
 sub refresh {
 	my $self = shift;
 	my $doc = _CURRENT(@_)->document ? 1 : 0;
