@@ -9,7 +9,7 @@ use Padre::Wx       ();
 use Padre::Wx::Menu ();
 use Padre::Current qw{_CURRENT};
 
-our $VERSION = '0.49';
+our $VERSION = '0.50';
 our @ISA     = 'Padre::Wx::Menu';
 
 #####################################################################
@@ -27,106 +27,52 @@ sub new {
 	$self->{alt}  = [];
 
 	# File Navigation
-	$self->{window_next_file} = $self->add_menu_item(
+	$self->{window_next_file} = $self->add_menu_action(
 		$self,
-		name       => 'window.next_file',
-		label      => Wx::gettext('Next File'),
-		shortcut   => 'Ctrl-TAB',
-		menu_event => sub {
-			Padre::Wx::Main::on_next_pane(@_);
-		},
+		'window.next_file',
 	);
 
-	$self->{window_previous_file} = $self->add_menu_item(
+	$self->{window_previous_file} = $self->add_menu_action(
 		$self,
-		name       => 'window.previous_file',
-		label      => Wx::gettext('Previous File'),
-		shortcut   => 'Ctrl-Shift-TAB',
-		menu_event => sub {
-			Padre::Wx::Main::on_prev_pane(@_);
-		},
+		'window.previous_file',
 	);
 
-	$self->{window_last_visited_file} = $self->add_menu_item(
+	$self->{window_last_visited_file} = $self->add_menu_action(
 		$self,
-		name       => 'window.last_visited_file',
-		label      => Wx::gettext('Last Visited File'),
-		shortcut   => 'Ctrl-Shift-P',
-		menu_event => sub {
-			Padre::Wx::Main::on_last_visited_pane(@_);
-		},
+		'window.last_visited_file',
 	);
 
-	$self->{window_right_click} = $self->add_menu_item(
+	$self->{window_right_click} = $self->add_menu_action(
 		$self,
-		name       => 'window.right_click',
-		label      => Wx::gettext('Right Click'),
-		shortcut   => 'Alt-/',
-		menu_event => sub {
-			my $editor = $_[0]->current->editor;
-			if ($editor) {
-				$editor->on_right_down( $_[1] );
-			}
-		},
+		'window.right_click',
 	);
 
 	$self->AppendSeparator;
 
 	# Window Navigation
-	$self->{window_goto_functions_window} = $self->add_menu_item(
+	$self->{window_goto_functions_window} = $self->add_menu_action(
 		$self,
-		name       => 'window.goto_functions_window',
-		label      => Wx::gettext('GoTo Functions Window'),
-		shortcut   => 'Alt-N',
-		menu_event => sub {
-			$_[0]->refresh_functions( $_[0]->current );
-			$_[0]->show_functions(1);
-			$_[0]->functions->focus_on_search;
-		},
+		'window.goto_functions_window',
 	);
 
-	$self->{window_goto_outline_window} = $self->add_menu_item(
+	$self->{window_goto_outline_window} = $self->add_menu_action(
 		$self,
-		name       => 'window.goto_outline_window',
-		label      => Wx::gettext('GoTo Outline Window'),
-		shortcut   => 'Alt-L',
-		menu_event => sub {
-			$_[0]->show_outline(1);
-			$_[0]->outline->SetFocus;
-		},
+		'window.goto_outline_window',
 	);
 
-	$self->{window_goto_outline_window} = $self->add_menu_item(
+	$self->{window_goto_outline_window} = $self->add_menu_action(
 		$self,
-		name       => 'window.goto_output_window',
-		label      => Wx::gettext('GoTo Output Window'),
-		shortcut   => 'Alt-O',
-		menu_event => sub {
-			$_[0]->show_output(1);
-			$_[0]->output->SetFocus;
-		},
+		'window.goto_outline_window',
 	);
 
-	$self->{window_goto_syntax_check_window} = $self->add_menu_item(
+	$self->{window_goto_syntax_check_window} = $self->add_menu_action(
 		$self,
-		name       => 'window.goto_syntax_check_window',
-		label      => Wx::gettext('GoTo Syntax Check Window'),
-		shortcut   => 'Alt-C',
-		menu_event => sub {
-			$_[0]->show_syntax(1);
-			$_[0]->syntax->SetFocus;
-		},
+		'window.goto_syntax_check_window',
 	);
 
-	$self->{window_goto_main_window} = $self->add_menu_item(
+	$self->{window_goto_main_window} = $self->add_menu_action(
 		$self,
-		name       => 'window.goto_main_window',
-		label      => Wx::gettext('GoTo Main Window'),
-		shortcut   => 'Alt-M',
-		menu_event => sub {
-			my $editor = $_[0]->current->editor or return;
-			$editor->SetFocus;
-		},
+		'window.goto_main_window',
 	);
 
 	# We'll need to know the number of menu items there are
@@ -136,6 +82,12 @@ sub new {
 	return $self;
 }
 
+sub title {
+	my $self = shift;
+
+	return Wx::gettext('&Window');
+}
+
 sub refresh {
 	my $self     = shift;
 	my $current  = _CURRENT(@_);
